"""
Set of colour schemes to use when creating cloud
"""
red = ['lightcoral','salmon','darksalmon','lightsalmon','crimson','red','firebrick','darkred','indianred']
blue = ['lightblue','skyblue','lightskyblue','cornflowerblue','mediumslateblue','royalblue','mediumblue','darkblue','navy','midnightblue']
green = ['palegreen','lightgreen','mediumspringgreen','springgreen','mediumseagreen','seagreen','forestgreen','green','darkgreen']
pink = ['pink','lightpink','hotpink','deeppink','mediumvioletred','palevioletred']
brown = ['sandybrown','goldenrod','darkgoldenrod','peru','chocolate','saddlebrown','sienna','brown','maroon']
white = ['snow','honeydew','mintcream','azure','aliceblue','ghostwhite','whitesmoke','seashell','beige','oldlace','floralwhite','ivory','antiquewhite','linen','lavenderblush','mistyrose']
gray = ['gainsboro','lightgray','silver','darkgray','gray','dimgray','lightslategray','slategray','darkslategray']
orange = ['coral','tomato','lightsalmon','orangered','darkorange','orange']
yellow = ['lightgoldenrodyellow','papayawhip','moccasin','peachpuff','palegoldenrod','khaki','darkkhaki']
multi = ['firebrick', 'darkgreen', 'midnightblue','darkorange','mediumpurple']