from pkg_resources import resource_filename

mask_ellipse = resource_filename('ajnwordcloud', '/mask_image/circle.png')
mask_roundrect = resource_filename('ajnwordcloud', '/mask_image/roundrect.png')
mask_speech = resource_filename('ajnwordcloud', '/mask_image/speech.png')
mask_cloud = resource_filename('ajnwordcloud', '/mask_image/cloud.png')
mask_star5 = resource_filename('ajnwordcloud', '/mask_image/star5.png')
mask_star6 = resource_filename('ajnwordcloud', '/mask_image/star6.png')
mask_thought = resource_filename('ajnwordcloud', '/mask_image/thought.png')
mask_heart = resource_filename('ajnwordcloud', '/mask_image/heart.png')
mask_xmas_tree = resource_filename('ajnwordcloud', '/mask_image/tree.png')
mask_usa = resource_filename('ajnwordcloud', '/mask_image/usa.png')
mask_uk = resource_filename('ajnwordcloud', '/mask_image/uk.png')
mask_alien = resource_filename('ajnwordcloud', '/mask_image/alien.png')