from pkg_resources import resource_filename

font_xkcd = resource_filename('ajnwordcloud', '/font/xkcd.otf')
font_mouse_memoirs = resource_filename('ajnwordcloud', '/font/MouseMemoirs.ttf')
font_chunkfive = resource_filename('ajnwordcloud', '/font/Chunkfive.otf')