from .core import wordcloud
from .data import count_words, load_csv, load_txt
from .colours import red, green, blue, yellow, orange, pink, brown, white, gray, multi
from .fonts import font_xkcd, font_mouse_memoirs, font_chunkfive
from .mask_images import mask_ellipse, mask_roundrect, mask_cloud, mask_thought, mask_speech, mask_star5, mask_star6, mask_xmas_tree, mask_usa, mask_heart, mask_alien 
           
__version__ = '0.2.3'